/**
 *  Java GUI Tutorial 
 *  TabbedPaneExample.java
 *
 *  @autor Gabor Nemeth, HUNGARY 2007
 *    
 *  Licence: free for non-commercial use
 *
 *  This is a sample program without guarantee and liability.
 *  
 *
 **/

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.event.*;


public class TabbedPaneExample extends JFrame implements ActionListener {

  private JTabbedPane tabbedPane;
  
  private int COUNTER = 0;
  private Menu menu;
  private MenuItem addTabItem;
  private MenuItem removeTabItem;
  private MenuItem exitItem;
  private MenuItem tabsToRightItem;
  private MenuItem tabsToLeftItem;
  private MenuItem tabsToTopItem;
  private MenuItem tabsToBottomItem;
  private MenuBar menubar;
  
  public TabbedPaneExample() {
    super("TabbedPane example");
    
    
    tabbedPane = new JTabbedPane(JTabbedPane.TOP);
    this.setSize(300,200);
    
    menubar = new MenuBar();
    this.setMenuBar(menubar);
    menu = new Menu("Tabs");
    addTabItem = new MenuItem("Add new tab");
    removeTabItem = new MenuItem("Remove tab");
    exitItem = new MenuItem("Exit");
    
    tabsToRightItem = new MenuItem("Tabs to right");
    tabsToLeftItem = new MenuItem("Tabs to left");
    tabsToTopItem = new MenuItem("Tabs to top");
    tabsToBottomItem = new MenuItem("Tabs to bottom");
    
    menu.add(addTabItem);
    menu.add(removeTabItem);
    menu.addSeparator();
    menu.add(tabsToRightItem);
    menu.add(tabsToLeftItem);
    menu.add(tabsToTopItem);
    menu.add(tabsToBottomItem);
    menu.addSeparator();
    menu.add(exitItem);
    
    menubar.add(menu);
    
    this.getContentPane().add(tabbedPane);
    addTabItem.addActionListener(this);
    removeTabItem.addActionListener(this);
    exitItem.addActionListener(this);
    tabsToRightItem.addActionListener(this);
    tabsToTopItem.addActionListener(this);
    tabsToLeftItem.addActionListener(this);
    tabsToBottomItem.addActionListener(this);
    
  }
  
  public void actionPerformed(ActionEvent e) {
    if(e.getSource().equals(addTabItem)) {
      tabbedPane.addTab("Tab "+this.COUNTER, new JLabel("Label "+this.COUNTER));
      this.COUNTER++;
    }
    if(e.getSource().equals(removeTabItem)) {
      int index = tabbedPane.getSelectedIndex();
      tabbedPane.remove(index);
    }
    if(e.getSource().equals(exitItem)) {
      this.dispose();
      System.exit(0);
    }
    
    if(e.getSource().equals(tabsToRightItem)) {
      this.tabbedPane.setTabPlacement(JTabbedPane.RIGHT);
    }
    if(e.getSource().equals(tabsToLeftItem)) {
      this.tabbedPane.setTabPlacement(JTabbedPane.LEFT);
    }
    if(e.getSource().equals(tabsToTopItem)) {
      this.tabbedPane.setTabPlacement(JTabbedPane.TOP);
    }
    if(e.getSource().equals(tabsToBottomItem)) {
      this.tabbedPane.setTabPlacement(JTabbedPane.BOTTOM);
    }
  }
  
  
  public static void main(String[] args) {
    TabbedPaneExample frame = new TabbedPaneExample();
    frame.setVisible(true);
    
    // this is an implementation of window listener
    // the program will be stopped if you close the main frame
    WindowListener listener = new WindowAdapter() {
      public void windowClosing(WindowEvent we) {
        System.exit(0);
      }
    };
    frame.addWindowListener(listener);
  }

}

